#!/usr/bin/env gnuplot

reset

## resemble Iverson 2010 fig2a

#set terminal pdfcairo size 4.45 cm, 4.45 cm font ",10"
set terminal pdfcairo enhanced color size 7 cm, 4.5 cm font ",10"

set margins 8,2,3.2,1

set colorsequence podo

unset xrange
unset yrange
unset logscale x
set xtics 50
set ytics 25
set ylabel "Shear stress {/Symbol t} [kPa]" offset 1.0
set xlabel "Eff. normal stress {/Symbol s}_n' [kPa]"
set xrange [0:200]
set yrange [0:120]

set angles degrees
caesar(x)        = (x >= 50 && x <= 5000) ? tan(28)*x - 6.5 : 1/0  # Rathbun et al., 2008, saturated Caesar till
storglaciaren(x) = (x >= 25 && x <= 150)  ? tan(26.3)*x + 5 : 1/0  # Iverson et al., 1998
two_rivers(x)    = (x >= 30 && x <= 145)  ? tan(17.8)*x + 14 : 1/0 # Iverson et al., 1998
# Des Moines Lobe till properties extracted from Iverson 2010 plot, mc_des_moines_lobe.dat
wis(x)           = (x >= 20 && x <= 310)  ? tan(24)*x + 3 : 1/0    # Tulaczyk et al., 2000

#set key bottom right font ",9" samplen 1.5 maxrows 4
set key top left reverse Left font ",8" samplen 1.5 maxrows 4 width -3

set label "c" at screen 0.02,0.95 font ",12"

plot \
	caesar(x)                w l lc 1 lw 2 t "Caesar till", \
	"mc_caesar.txt"          u ($1):($2*$1 - 6.5) w l dashtype 2 lc 1 lw 2 t "{/:Bold CNGF-PF}", \
	storglaciaren(x)         w l lc 2 lw 2 t "Storglaciaren till", \
	"mc_storglaciaren.txt"   u ($1):($2*$1 + 5) w l dashtype 2 lc 2 lw 2 t "{/:Bold CNGF-PF}", \
	two_rivers(x)            w l lc 3 lw 2 t "Two Rivers till", \
	"mc_two_rivers.txt"      u ($1):($2*$1 + 14) w l dashtype 2 lc 3 lw 2 t "{/:Bold CNGF-PF}", \
	wis(x)                   w l lc 4 lw 2 t "WIS till", \
	"mc_wis.txt"             u ($1):($2*$1 + 3) w l dashtype 2 lc 4 lw 2 t "{/:Bold CNGF-PF}"
