#!/usr/bin/env gnuplot

reset

#set terminal pdfcairo color size 7.5 cm, 5.0 cm
set terminal pdfcairo enhanced color size 15.0 cm, 15.0 cm
set multiplot layout 4,3 \
	margins 0.09,0.97,0.09,0.97 \
	spacing 0.05,0.08

load 'BlueSeq.plt'

set xrange [0:300]
set yrange [0:1]

set key bottom right font ",10" samplen 2.0

set xlabel "Shear velocity [m/a]"
set ylabel "Vertical position, z [m]"

plot \
	"d.1e-2.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 5 lw 1 t "d = 1e-2", \
	"d.2e-3.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 4 lw 1 t "d = 2e-3", \
	"d.1e-3.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 3 lw 1 t "d = 1e-3", \
	"d.2e-4.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 2 lw 1 t "d = 2e-4", \
	"d.1e-4.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 1 lw 1 t "d* = 1e-4"

unset ylabel

plot \
	"mu_s.0.5.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 5 lw 1 t "{/Symbol m}_s = 0.50", \
	"mu_s.0.45.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 4 lw 1 t "{/Symbol m}_s = 0.45", \
	"mu_s.0.4.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 3 lw 1 t "{/Symbol m}_s* = 0.40", \
	"mu_s.0.35.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 2 lw 1 t "{/Symbol m}_s = 0.35", \
	"mu_s.0.3.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 1 lw 1 t "{/Symbol m}_s = 0.30"

plot \
	"C.0.0.output00000.txt"  u ($2*365.25*24*60*60):1 w l ls 5 lw 1 t "C* = 0 kPa", \
	"C.5e3.output00000.txt"  u ($2*365.25*24*60*60):1 w l ls 4 lw 1 t "C = 5 kPa", \
	"C.10e3.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 3 lw 1 t "C = 10 kPa", \
	"C.20e3.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 2 lw 1 t "C = 20 kPa", \
	"C.30e3.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 1 lw 1 t "C = 30 kPa"

set ylabel "Vertical position, z [m]"
set ytics

plot \
	"A.1e-10.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 5 lw 1 t "A {/Symbol \273} 0.0", \
	"A.0.2.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 5 lw 1 t "A = 0.2", \
	"A.0.4.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 3 lw 1 t "A* = 0.4", \
	"A.0.6.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 1 lw 1 t "A = 0.6", \
	"A.0.8.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 1 lw 1 t "A = 0.8", \
	"A.1.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 1 lw 1 t "A = 1.0"

unset ylabel

plot \
	"b.0.1.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 5 lw 1 t "b = 0.1", \
	"b.0.3.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 4 lw 1 t "b = 0.3", \
	"b.0.5.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 3 lw 1 t "b = 0.5", \
	"b.0.7.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 2 lw 1 t "b = 0.7", \
	"b.0.9.output00000.txt" u ($2*365.25*24*60*60):1 w l ls 1 lw 1 t "b* = 0.9"

plot \
	"L_z.0.10.output00000.txt"  u ($2*365.25*24*60*60):($1+0.9)   w l ls 6 lw 1 t "L_z = 0.1 m", \
	"L_z.0.20.output00000.txt"  u ($2*365.25*24*60*60):($1+0.8)   w l ls 5 lw 1 t "L_z = 0.2 m", \
	"L_z.0.40.output00000.txt"  u ($2*365.25*24*60*60):($1+0.6)   w l ls 4 lw 1 t "L_z = 0.4 m", \
	"L_z.0.60.output00000.txt"  u ($2*365.25*24*60*60):($1+0.4)   w l ls 3 lw 1 t "L_z = 0.6 m", \
	"L_z.0.80.output00000.txt"  u ($2*365.25*24*60*60):($1+0.2)   w l ls 2 lw 1 t "L_z = 0.8 m", \
	"L_z.1.0.output00000.txt"   u ($2*365.25*24*60*60):($1)       w l ls 1 lw 1 t "L_z* = 1.0 m"

unset xrange
unset yrange

set yrange [0:1]

set ylabel "Bulk friction, {/Symbol m} [-]"

set xrange [8e-5:3e-2]
set format x "10^{%T}"
set xlabel "Grain size, d [m]"
set logscale x
plot "d.txt"    w lp t ""
unset logscale x
unset format x

unset ylabel

set xrange [0.18:0.72]
set xlabel "Grain friction, {/Symbol m}_s [-]"
plot "mu_s.txt" w lp t ""

set xrange [-2:32]
set xlabel "Cohesion, C [kPa]"
plot "C.txt" u ($1/1000):2 w lp t ""

set ylabel "Bulk friction, {/Symbol m} [-]"

#set xrange [0.28:0.52]
#set xrange [0.18:0.72]
set xrange [-0.02:1.02]
set xlabel "Nonlocal amplitude, A [-]"
plot "A.txt"    w lp t ""

unset ylabel

set xrange [0:1]
set xlabel "Rate dependence, b [-]"
plot "b.txt"    w lp t ""

set xrange [-0.05:1.05]
set xlabel "Bed thickness, L_z [m]"
plot "L_z.txt"  w lp t ""
