#!/usr/bin/env gnuplot
reset

set terminal pdfcairo color size 15 cm, 10 cm

set multiplot layout 4,1 \
	margins 0.15,0.88,0.13,0.95 \
	spacing 0.0,0.03

file_interval_seconds=600.0
conv=1.0/(24.0*3600.0/file_interval_seconds) * 140.0/138.5

set key top right samplen 1.0
unset xlabel
set xtics format ""
set xrange [0:140]
set yrange [0:380]
set ylabel "[kPa]"
set ytics 100

plot \
"timeseries.txt" u ($0*conv):($2/1000) w l lw 2 lc "black" t "effective normal stress", \
"" u ($0*conv):($3/1000) w l lw 2 lt 3 dt "-" t "water pressure"

unset yrange
set yrange [5e-20:1e-15]
set ytics (1e-19,1e-18,1e-17,1e-16)
set ylabel "Permeability [m^2]"
set logscale y
plot "max_strainrate_depth.txt" u ($0*conv):3 w l lw 2 lt 5 t ""
unset logscale y

unset ylabel
unset ytics
set yrange [0:100]
set y2range [0:100]
set y2tics 20
set y2label "Shear stress [kPa]"
plot "timeseries.txt" u ($0*conv):($4*$2/1000) w l lw 2 lt 1 t ""

set xtics format "%g"
unset y2label
unset y2tics
set ytics 0.5
set yrange [3.0:0.0]
set xlabel "Time [d]"
set ylabel "Depth of max. strain rate [m]"
plot "max_strainrate_depth.txt" u ($0*conv):(8.0 - $1) w l lw 2 lt 4 t ""

unset multiplot
