#!/usr/bin/env gnuplot

reset

set terminal pdfcairo color size 17.8 cm, 4.45 cm font ",10"

set multiplot layout 1,3 \
	margin 0.07,0.92,0.25,0.86 \
	spacing 0.17,0.0

set key bottom right #samplen 0.9

# hydraulic parameters
D_min = 1e-9
D_max = 1e-3

# forcing parameters
f_min = 0.5*1.0/(24*365)/36000.0
f_max = 2.0/3600.0

# f: frequency, D: diffusivity
skindepth(f,D) = (D/(3.141592654*f))**(0.5)  # f: 1/s

set xlabel "Forcing frequency {/:Italic f} [s^{-1}]"
set ylabel "Diffusivity {/:Italic D} [m^2/s]"
set cblabel "Skin depth {/:Italic d}_s [m]"

set logscale xyzcb
set xrange [f_min:f_max]
set yrange [D_min:D_max]
set samples 100
set isosamples 60

# Generate contours
set view map
unset surface
set xtics rotate by 90
set ytics offset 1
set format x '10^{%T}'
set format y '10^{%T}'

set pm3d

label_y = 3e-9
x=1.0/3600.0
set arrow from x,D_min to x,D_max nohead lc "white" front
set label "hourly" at x,label_y rotate by 90 front offset screen -0.01,0 textcolor "white"
x=1.0/3600.0/24.0
set arrow from x,D_min to x,D_max nohead lc "white" front
set label "daily" at x,label_y rotate by 90 front offset screen -0.01,0 textcolor "white"
x=1.0/3600.0/24.0/30.0
set arrow from x,D_min to x,D_max nohead lc "white" front
set label "monthly" at x,label_y rotate by 90 front offset screen -0.01,0 textcolor "white"
x=1.0/3600.0/24.0/365.0
set arrow from x,D_min to x,D_max nohead lc "white" front
set label "yearly" at x,label_y rotate by 90 front offset screen -0.01,0 textcolor "white"

splot skindepth(x,y) notitle with lines palette, \
      skindepth(x,y) with pm3d notitle

reset
set pm3d

x=1.0/3600.0
set arrow from x,D_min to x,D_max nohead lc "white" front
set label "hourly" at x,label_y rotate by 90 front offset screen -0.01,0 textcolor "white"
x=1.0/3600.0/24.0
set arrow from x,D_min to x,D_max nohead lc "white" front
set label "daily" at x,label_y rotate by 90 front offset screen -0.01,0 textcolor "white"
x=1.0/3600.0/24.0/30.0
set arrow from x,D_min to x,D_max nohead lc "white" front
set label "monthly" at x,label_y rotate by 90 front offset screen -0.01,0 textcolor "white"
x=1.0/3600.0/24.0/365.0
set arrow from x,D_min to x,D_max nohead lc "white" front
set label "yearly" at x,label_y rotate by 90 front offset screen -0.01,0 textcolor "white"

set label "a" at screen 0.01,0.95 font ",12"
set label "b" at screen 0.35,0.95 font ",12"
set label "c" at screen 0.70,0.95 font ",12"

set xlabel "Forcing frequency {/:Italic f} [s^{-1}]"
set ylabel "Diffusivity {/:Italic D} [m^2/s]"
set cblabel "Max. deformation depth [m]"

set xrange [f_min:f_max]
set yrange [D_min:D_max]
set xtics rotate by 90
set ytics offset 1
set format x '10^{%T}'
set format y '10^{%T}'

set view map scale 1
set style data pm3d
set style function pm3d
set xyplane relative 0
set nomcbtics
set pm3d implicit at b
set pm3d scansforward
#set pm3d interpolate 10,10
set logscale xy

#unset colorbox

set title "{/:Italic A}_f = 10 kPa"
splot 'max_depth_ampl10e3.txt' notitle with lines palette, \
      '' with pm3d notitle

#unset ylabel
#set colorbox
set title "{/:Italic A}_f = 100 kPa"
splot 'max_depth_ampl100e3.txt' notitle with lines palette, \
      '' with pm3d notitle
