#!/usr/bin/env gnuplot

set terminal pdfcairo color size 17.8 cm, 10.0 cm font ",10"

set colorsequence podo
set multiplot

file_interval=60*10
plot_interval=60*60
inc=plot_interval/file_interval
L_z=8.0
set yrange [4.0:0.0]
set ytics 1.0

t0 = 48*inc - 1
tend = 72*inc - 1

filename(t) = sprintf('rate/sim.output%05d.txt', t)

set pm3d map
#set palette rgb 10,6,6
set palette

set ylabel "{/:Normal Depth [m]}" offset 0.5

set origin 0.06, 0.0
set size 0.313, 0.46
xmin = 0.0
xmax = 200.0
set xrange [xmin:xmax]
set arrow from 88,skin_depth to xmax,skin_depth nohead lc black front
set colorbox user origin 0.001, 0.09 size 0.015, 0.34
set cblabel "Time [d]"
set cbrange [2:3]
set cbtics 0.2
set label "d" font ",11" at graph 0.00,1.1
set xlabel "{/:Normal Effective normal stress [kPa]}"
plot for [t = t0:tend:inc*2] filename(t) u ($3/1e3):(L_z - $1):(t*file_interval/(24.*3600.)) w l lc palette lw 2 t ""
unset arrow
unset colorbox

set origin 0.373, 0.0
set size 0.313, 0.46
unset label
set label "e (Speed controlled)" font ",11" at graph 0.00,1.1
set xlabel "{/:Normal Shear strain rate [1/d]}" font ",10"
xmin = -2.0
xmax = 50.0
set xrange [xmin:xmax]
set arrow from xmin,max_def_depth to 15,max_def_depth nohead front lc black dashtype 2
plot for [t = t0:tend:inc*2] filename(t) u ($6*60*60*24):(L_z - $1):(t*file_interval/(24.*3600.)) w l lc palette lw 2 t ""
unset format x
unset arrow

filename(t) = sprintf('stress/sim.output%05d.txt', t)

set origin 0.686, 0.0
set size 0.313, 0.46
unset label
set label "f (Stress controlled)" font ",11" at graph 0.00,1.1
set xlabel "{/:Normal Shear strain rate [1/min]}"
xmin = -1.0
xmax = 12.0
set xrange [xmin:xmax]
plot for [t = t0:tend:inc*2] filename(t) u ($6*60):(L_z - $1):(t*file_interval/(24.*3600.)) w l lc palette lw 2 t ""
unset format x

set origin 0.043, 0.5
set size 0.330, 0.46
set key top right samplen 1.0 font ",10"
set xrange [0:7]
set yrange [0:240]
set ylabel "{/:Normal [kPa]}"
set xlabel "{/:Normal Time [d]}"
set xtics 1
set ytics 50
unset label
set label "a" font ",11" at graph 0.00,1.1
plot \
"rate/timeseries.txt" u ($0/1008*7):($2/1000) w l lw 2 lc "black" t "Effective normal stress", \
"" u ($0/1008*7):($3/1000) w l lw 2 lt 3 dt "-" t "Water pressure"

set origin 0.373, 0.5
set size 0.313, 0.46
unset label
set label "b (Speed controlled)" font ",11" at graph 0.00,1.1
unset y2label
unset y2tics
set ytics 1.0
set yrange [4.0:0.0]
set ylabel "{/:Normal Depth of max. strain rate [m]}"
set arrow from 0,max_def_depth to 7,max_def_depth nohead front lc black dashtype 2
plot "rate/max_strainrate_depth.txt" u ($0/1008*7):(8.0 - $1) w l lw 2 t ""

set origin 0.686, 0.5
set size 0.313, 0.46
unset arrow
unset label
set label "c (Stress controlled)" font ",11" at graph 0.00,1.1
unset y2label
unset y2tics
set yrange [0.0:9.8]
set ytics 2.0
set ylabel "{/:Normal Shear speed [km/d]}"
plot "stress/timeseries.txt" u ($0/1008*7):($1*3600.*24./1000.) w l lw 2 lc "red" t ""

unset label
filename(t) = sprintf('rate/sim.output%05d.txt', t)
set origin 0.498, 0.11
set size 0.17, 0.28
set xlabel "{/:Normal Shear speed [km/a]}" font ",8" offset 0,0.7
set ylabel "Depth [m]" font ",8" offset 0.7,0.0
set ytics 1 font ",8"
set xtics 0.5 font ",8"
unset arrow
xmin = -0.1
xmax = 1.1
set arrow from xmin,max_def_depth to xmax,max_def_depth nohead front lc black dashtype 2
set xrange [xmin:xmax]
set yrange [4.0:0.0]
plot for [t = t0:tend:inc*2] filename(t) u ($2*60*60*24*365/1000):(L_z - $1):(t*file_interval/(24.*3600.)) w l lc palette lw 1 t ""

filename(t) = sprintf('stress/sim.output%05d.txt', t)
set origin 0.81, 0.11
set size 0.17, 0.28
set xlabel "{/:Normal Shear speed [km/d]}" font ",8"
unset arrow
xmin = -1
xmax = 10
set xrange [xmin:xmax]
set xtics 2
plot for [t = t0:tend:inc*2] filename(t) u ($2*60*60*24/1000):(L_z - $1):(t*file_interval/(24.*3600.)) w l lc palette lw 1 t ""

filename(t) = sprintf('stress/sim.output%05d.txt', t)
set origin 0.095, 0.09
set size 0.14, 0.23
set xlabel "{/:Normal Water pressure [kPa]}" font ",8" offset 0,1.3
set ylabel ""
unset arrow
xmin = 0
xmax = 200.0
set arrow from xmin,skin_depth to xmax,skin_depth nohead lc black front
set xrange [xmin:xmax]
set xtics 100 offset 0,0.5
set ytics 2 offset 0.5
plot for [t = t0:tend:inc*2] filename(t) u ($4/1e3):(L_z - $1):(t*file_interval/(24.*3600.)) w l lc palette lw 1 t ""

unset multiplot
