#!/usr/bin/env gnuplot

#set terminal pdfcairo color size 7.5 cm, 7.5 cm
#set terminal pdfcairo color size 13.35 cm, 4.45 cm font ",10"
#set terminal pdfcairo color size 10.68 cm, 4.45 cm font ",10"
#set terminal pdfcairo color size 11.87 cm, 4.45 cm font ",10"
set terminal pdfcairo color size 11.87 cm, 4.45 cm font ",10"
set multiplot layout 1,4 \
	margins 0.05,0.98,0.23,0.90 \
	spacing 0.02,0.02

set key bottom right #samplen 0.9

file_interval=60*10
plot_interval=60*60
inc=plot_interval/file_interval
#set yrange [4.0:8.0]
L_z=8.0
set yrange [4.0:0.0]

t0 = 47*inc
tend = 71*inc

filename(t) = sprintf('sim.output%05d.txt', t)

set pm3d map
#set palette rgb 10,6,6
set palette

unset colorbox
set ylabel "{/:Normal Depth [m]}" offset 1.8
xmin = 0.0
xmax = 200.0
set xrange [xmin:xmax]
set arrow from xmin,skin_depth to xmax,skin_depth nohead lc black front
set arrow from xmin,max_def_depth to xmax,max_def_depth nohead front lc black dashtype 2
set label "A" at screen 0.090,0.97 font ",12"
set xlabel "{/:Normal Water pressure [kPa]}"
plot for [t = t0:tend:inc] filename(t) u ($4/1e3):(L_z - $1):(t-t0) w l lc palette lw 1 t ""

unset colorbox
set ylabel ""
unset ytics
xmin = 0.0
xmax = 200.0
set xrange [xmin:xmax]
set arrow from xmin,skin_depth to xmax,skin_depth nohead lc black front
set arrow from xmin,max_def_depth to xmax,max_def_depth nohead front lc black dashtype 2
set label "B" at screen 0.220,0.97 font ",12"
set xlabel "{/:Normal Eff. normal stress [kPa]}"
plot for [t = t0:tend:inc] filename(t) u ($3/1e3):(L_z - $1):(t-t0) w l lc palette lw 1 t ""

unset label
set label "C (speed controlled)" at screen 0.395,0.97 font ",12"
set xlabel "{/:Normal Shear speed [km/a]}"
set ylabel ""
unset ytics
unset arrow
xmin = -0.1
xmax = 1.1
set xrange [xmin:xmax]
set arrow from xmin,skin_depth to xmax,skin_depth nohead lc black front
set arrow from xmin,max_def_depth to xmax,max_def_depth nohead front lc black dashtype 2
plot for [t = t0:tend:inc] filename(t) u ($2*60*60*24*365/1000):(L_z - $1):(t-t0) w l lc palette lw 1 t ""

unset label
set label "D (speed controlled)" at screen 0.705,0.97 font ",12"
set xlabel "{/:Normal Shear strain rate [1/d]}"
set ylabel ""
xmin = -2.0
xmax = 22.0
set xrange [xmin:xmax]
set arrow from xmin,skin_depth to xmax,skin_depth nohead lc black front
set arrow from xmin,max_def_depth to xmax,max_def_depth nohead front lc black dashtype 2
unset ytics
plot for [t = t0:tend:inc] filename(t) u ($6*60*60*24):(L_z - $1):(t-t0) w l lc palette lw 1 t ""
unset format x

unset multiplot
