#!/usr/bin/env gnuplot

#set terminal pdfcairo color size 7.5 cm, 7.5 cm
set terminal pdfcairo color size 15.0 cm, 5.0 cm
set multiplot layout 1,4 \
	margins 0.09,0.97,0.23,0.95 \
	spacing 0.03,0.03

set yrange [4.0:8.0]

set key bottom right #samplen 0.9

file_interval=60*10
plot_interval=60*60
inc=plot_interval/file_interval

#t0 = 47*inc
#tend = 71*inc
t0 = 20*inc
tend = 47*inc

filename(t) = sprintf('sim.output%05d.txt', t)

set pm3d map
set palette rgb 10,6,6

#load '../skindepth.gp'
#k = 2e-17
#f = 1.0/(3600.0*24.0)
#f(x) = 8.0 - skindepth(f,k)

set label "{/:Bold a}" at graph 0.90,0.93
unset colorbox
set xlabel "{/:Normal Water pressure [kPa]}"
set ylabel "{/:Normal Vertical position [m]}"
set xrange [0:200]
set arrow from 0,skin_depth to 200,skin_depth nohead lc black front
set arrow from 0,max_def_depth to 200,max_def_depth nohead front lc black dashtype 2
plot for [t = t0:tend:inc] filename(t) u ($4/1e3):1:(t-t0) w l lc palette lw 1 t ""

unset label
set label "{/:Bold b}" at graph 0.90,0.93
set xlabel "{/:Normal Eff. normal stress [kPa]}"
set ylabel ""
set xrange [0:200]
unset ytics
plot for [t = t0:tend:inc] filename(t) u ($3/1e3):1:(t-t0) w l lc palette lw 1 t ""

unset label
set label "{/:Bold c}" at graph 0.90,0.93
set xlabel "{/:Normal Shear velocity [km/a]}"
set ylabel ""
set xrange [0.0:1.0]
#unset xrange
#set xtics (0,0.02,0.04,0.06)
unset ytics
unset arrow
set arrow from 0,skin_depth to 1,skin_depth nohead lc black front
set arrow from 0,max_def_depth to 1,max_def_depth nohead front lc black dashtype 2
plot for [t = t0:tend:inc] filename(t) u ($2*60*60*24*365/1000):1:(t-t0) w l lc palette lw 1 t ""

unset label
set label "{/:Bold d}" at graph 0.90,0.93
set xlabel "{/:Normal Shear strain rate [1/d]}"
set ylabel ""
set xrange [0:20]
unset ytics
unset arrow
set arrow from 0,skin_depth to 20,skin_depth nohead lc black front
set arrow from 0,max_def_depth to 20,max_def_depth nohead front lc black dashtype 2
plot for [t = t0:tend:inc] filename(t) u ($6*60*60*24):1:(t-t0) w l lc palette lw 1 t ""
unset format x

unset multiplot
